==> redux-orm-0.14.0-rc.3.tgz: package/es/selectors/MapSelectorSpec.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _createClass from "@babel/runtime/helpers/createClass";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import ModelBasedSelectorSpec from './ModelBasedSelectorSpec';
import idArgSelector from './idArgSelector';

var MapSelectorSpec =
/*#__PURE__*/
function (_ModelBasedSelectorSp) {
  _inheritsLoose(MapSelectorSpec, _ModelBasedSelectorSp);

  function MapSelectorSpec(_ref) {
    var _this;

    var field = _ref.field,
        accessorName = _ref.accessorName,
        selector = _ref.selector,
        other = _objectWithoutProperties(_ref, ["field", "accessorName", "selector"]);

    _this = _ModelBasedSelectorSp.call(this, other) || this;
    _this._field = field;
    _this._accessorName = accessorName;
    _this._selector = selector;
    return _this;
  }

  var _proto = MapSelectorSpec.prototype;

  _proto.valueForInstance = function valueForInstance(instance, session, state) {
    var _this2 = this;

    if (!instance) return null;
    var value = instance[this._accessorName];
    if (!value) return null;
    var mapIdAttribute = session[this._field.toModelName].idAttribute;
    return value.toRefArray().map(function (ref) {
      return _this2._selector(state, ref[mapIdAttribute]);
    });
  };

  _createClass(MapSelectorSpec, [{
    key: "key",
    get: function get() {
      return this._selector;
    }
  }, {
    key: "dependencies",
    get: function get() {
      return [this._orm, idArgSelector, function (state) {
        return state;
      }];
    }
  }]);

  return MapSelectorSpec;
}(ModelBasedSelectorSpec);

export { MapSelectorSpec as default };

==> redux-orm-0.15.0.tgz: package/es/selectors/MapSelectorSpec.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _createClass from "@babel/runtime/helpers/createClass";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import ModelBasedSelectorSpec from "./ModelBasedSelectorSpec";
import idArgSelector from "./idArgSelector";

var MapSelectorSpec =
/*#__PURE__*/
function (_ModelBasedSelectorSp) {
  _inheritsLoose(MapSelectorSpec, _ModelBasedSelectorSp);

  function MapSelectorSpec(_ref) {
    var _this;

    var field = _ref.field,
        accessorName = _ref.accessorName,
        selector = _ref.selector,
        other = _objectWithoutProperties(_ref, ["field", "accessorName", "selector"]);

    _this = _ModelBasedSelectorSp.call(this, other) || this;
    _this._field = field;
    _this._accessorName = accessorName;
    _this._selector = selector;
    return _this;
  }

  var _proto = MapSelectorSpec.prototype;

  _proto.valueForInstance = function valueForInstance(instance, session, state) {
    var _this2 = this;

    if (!instance) return null;
    var idAttribute = session[this._field.toModelName].idAttribute;
    return instance[this._accessorName].toRefArray().map(function (ref) {
      return _this2._selector(state, ref[idAttribute]);
    });
  };

  _createClass(MapSelectorSpec, [{
    key: "key",
    get: function get() {
      return this._selector;
    }
  }, {
    key: "dependencies",
    get: function get() {
      return [this._orm, idArgSelector, function (state) {
        return state;
      }];
    }
  }]);

  return MapSelectorSpec;
}(ModelBasedSelectorSpec);

export { MapSelectorSpec as default };
